/*
  theme-title: Solarized (auto)
  theme-description: Solarized theme that adapts to system preferences
*/

/* Default to dark theme */
@import url("solarized-dark.css");

@import url("solarized-light.css") screen and (prefers-color-scheme: light);
@import url("solarized-dark.css") screen and (prefers-color-scheme: dark);
