/* from settings/style.css */

/*
   GoToSocial
   Copyright (C) 2021-2023 GoToSocial Authors admin@gotosocial.org

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU Affero General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU Affero General Public License for more details.

   You should have received a copy of the GNU Affero General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/*
	This source file uses PostCSS syntax.
	See: https://postcss.org/
*/

body {
	grid-template-rows: auto 1fr;
}

.page-content {
	grid-column: 1 / span 3; /* stretch entire width, to fit panel + sidebar nav */
	width: 100%;
}

/* Don't inherit orange dot from base.css. */

ul li::before {
	content: initial;
}

#root {
	box-sizing: border-box;
	display: flex;
	justify-content: center;
	flex-wrap: wrap;
	margin: 0 1rem;
	gap: 1rem;
}

#root section.oauth {
		max-width: 92%;
		width: 60rem;
	}

#root section.with-sidebar {
		flex-grow: 100;
		flex-basis: 40rem;
		background: var(--bg-accent);
		padding: 2rem;
		border-radius: var(--br);
		max-width: 100%;
	}

#root section.with-sidebar > div,
		#root section.with-sidebar > form {
			display: flex;
			flex-direction: column;
			margin: 1rem 0;
		}

#root section.with-sidebar > div h1, #root section.with-sidebar > div h2, #root section.with-sidebar > div h3, #root section.with-sidebar > div h4, #root section.with-sidebar > div h5, #root section.with-sidebar > form h1, #root section.with-sidebar > form h2, #root section.with-sidebar > form h3, #root section.with-sidebar > form h4, #root section.with-sidebar > form h5 {
				margin: 0;
			}

#root section.with-sidebar > div:first-child, #root section.with-sidebar > form:first-child {
				margin-top: 0;
			}

#root section.with-sidebar > div:last-child, #root section.with-sidebar > form:last-child {
				margin-bottom: 0;
			}

#root section.with-sidebar > .error {
			display: grid; /* prevents error overflowing */
		}

#root .sidebar {
		flex-grow: 1;
		flex-basis: 20rem;
		align-self: start;
		justify-self: end;
		background: var(--bg);
		display: flex;
		flex-direction: column;
	}

#root .sidebar .account-card {
			grid-template-columns: auto 1fr auto;
		}

#root .sidebar .account-card img.avatar {
				width: 4rem;
				height: 4rem;
			}

#root .sidebar .account-card span {
				grid-row: 2;
			}

#root .sidebar .account-card .logout {
				font-size: 1.5rem;
				align-self: center;
				grid-row: 1 / span 2;
			}

#root .sidebar .account-card:hover {
				background: var(--list-entry-bg);
			}

nav.menu-tree ul {
		display: flex;
		flex-direction: column;
		list-style-type: none;
		margin: 0;
		padding: 0;
	}

nav.menu-tree .icon {
		margin-right: 0.5rem;
	}

/* top-level ul */

nav.menu-tree > ul {
		gap: 0.3rem;
		padding: 0.2rem;
	}

nav.menu-tree li.top-level { /* top-level categories, orange all-caps titles */
		border-top: 0.1rem solid var(--gray3);
		display: flex;
		flex-direction: column;
		gap: 0.3rem;
		margin: 0;
	}

nav.menu-tree li.top-level > a.title {
			text-decoration: none;
			color: var(--settings-nav-header-fg);
			padding: 0.5rem;
			padding-bottom: 0;
			margin: 0;
			font-size: 0.8rem;
			font-weight: bold;
			text-transform: uppercase;
		}

nav.menu-tree li.top-level > ul {
			gap: 0.2rem;
		}

/* second-level categories, expanding box, active shows nested */

nav.menu-tree li.expanding a {
			display: block;
			color: var(--fg);
			text-decoration: none;

			border: 0.1rem solid transparent;
			border-radius: var(--br);
			padding: 0.5rem;
			transition: background 0.1s;
		}

nav.menu-tree li.expanding a:hover {
				color: var(--settings-nav-fg-hover);
				background: var(--settings-nav-bg-hover);
			}

nav.menu-tree li.expanding a:focus, nav.menu-tree li.expanding a:active {
				border-color: var(--settings-nav-border-active);
				outline: none;
			}

nav.menu-tree li.expanding.active {
			border: 0.1rem solid var(--settings-nav-border-active);
			border-radius: var(--br);
			overflow: hidden;
		}

nav.menu-tree li.expanding.active a {
				transition: background 0s;
				border: none;
				color: var(--settings-nav-fg-active);
				background: var(--settings-nav-bg-active);
				font-weight: bold;
				border-radius: 0;
			}

/* Deeper nesting. */

nav.menu-tree li.nested a.title {
			padding-left: 1rem;
			font-weight: normal;
			color: var(--fg);
			background: var(--gray4);
		}

nav.menu-tree li.nested a.title:focus {
				color: var(--fg-accent);
				outline: none;
			}

nav.menu-tree li.nested a.title:hover {
				background: var(--settings-nav-bg-hover);
			}

nav.menu-tree li.nested.active > a.title {
			color: var(--fg-accent);
			font-weight: bold;
		}

nav.menu-tree li.nested.category > a.title::after {
					content: "▶";
					left: 0.8rem;
					bottom: 0.1rem;
					position: relative;
				}

nav.menu-tree li.nested.category.active > a.title::after {
						content: "▼";
						bottom: 0;
					}

nav.menu-tree li.nested.category.active > a.title {

					border-bottom: 0.15rem dotted var(--gray1);
}

nav.menu-tree li.nested.category li.nested > a.title {
				padding-left: 2rem;
			}

.capitalize {
	text-transform: capitalize;
}

input, select, textarea {
	box-sizing: border-box;
}

.error {
	color: var(--error-fg);
	background: var(--error-bg);
	border: 0.02rem solid var(--error-fg);
	border-radius: var(--br);
	font-weight: bold;
	padding: 0.5rem;
	white-space: pre-wrap;
	position: relative;
}

.error a {
		color: var(--error-link);
	}

.error .details {
		max-width: 100%;
		overflow: hidden;
		display: flex;
		flex-direction: column;
		gap: 0.5rem;
	}

.error pre {
		background: var(--bg);
		color: var(--fg);
		padding: 1rem;
		overflow: auto;
		margin: 0;
	}

.error.with-dismiss {
		display: flex;
		gap: 1rem;
		justify-content: space-between;
		align-items: center;
		align-items: center;
		flex-wrap: wrap;
		align-items: center;
		flex-wrap: wrap;
	}

.error.with-dismiss .dismiss {
			display: flex;
			flex-shrink: 0;
			align-items: center;
			align-self: stretch;
			gap: 0.25rem;
		}

.hidden {
	display: none;
}

.notImplemented {
	border: 2px solid rgb(70, 79, 88);
	background: repeating-linear-gradient(
		-45deg,
		#525c66,
		#525c66 10px,
		rgb(70, 79, 88) 10px,
		rgb(70, 79, 88) 20px
	) !important;
}

section.with-sidebar > div,
section.with-sidebar > form {
	display: flex;
	flex-direction: column;
	gap: 1rem;
}

section.with-sidebar > div input, section.with-sidebar > div textarea, section.with-sidebar > form input, section.with-sidebar > form textarea {
		width: 100%;
		line-height: 1.5rem;
	}

section.with-sidebar > div button, section.with-sidebar > form button {
		width: auto;
		align-self: flex-start;
		line-height: 1.5rem;
	}

section.with-sidebar > div input[type=checkbox], section.with-sidebar > form input[type=checkbox] {
		justify-self: start;
		width: initial;
	}

section.with-sidebar > div textarea, section.with-sidebar > form textarea {
		width: 100%;
	}

section.with-sidebar > div h1, section.with-sidebar > form h1 {
		margin-bottom: 0.5rem;
	}

section.with-sidebar > div .docslink, section.with-sidebar > form .docslink {
		font-size: 0.9em;
	}

section.with-sidebar > div .form-section-docs, section.with-sidebar > form .form-section-docs {
		margin-top: 1rem;
		margin-bottom: 0.5rem;
		
		border-left: 0.2rem solid var(--border-accent);
		padding-left: 0.4rem;

		display: flex;
		flex-direction: column;
		gap: 0.2rem;
	}

section.with-sidebar > div .labelinput .border, section.with-sidebar > form .labelinput .border {
		border-radius: 0.2rem;
		border: 0.15rem solid var(--border-accent);
		padding: 0.3rem;
		display: flex;
		flex-direction: column;
	}

section.with-sidebar > div .file-input.button, section.with-sidebar > form .file-input.button {
		display: inline-block;
		font-size: 1rem;
		font-weight: normal;
		padding: 0.3rem 0.3rem;
		align-self: flex-start;
		margin-right: 0.2rem;
	}

section.with-sidebar > div .labelinput, section.with-sidebar > div .labelselect, section.with-sidebar > form .labelinput, section.with-sidebar > form .labelselect {
		display: flex;
		flex-direction: column;
		gap: 0.4rem;
	}

section.with-sidebar > div .labelcheckbox, section.with-sidebar > form .labelcheckbox {
		display: flex;
		gap: 0.4rem;
	}

section.with-sidebar > div .titlesave, section.with-sidebar > form .titlesave {
		display: flex;
		flex-wrap: wrap;
		gap: 0.4rem;
	}

section.with-sidebar > div .select-wrapper, section.with-sidebar > form .select-wrapper {
		/*
			Selects are normalized in base.css to not have a down arrow on the side.
			Overcome this on settings panel forms by replacing the down arrow.
		*/
		position: relative;
	}

section.with-sidebar > div .select-wrapper::after, section.with-sidebar > form .select-wrapper::after {
			content: "▼";
			font-size: 0.8rem;
			top: 0.3rem;
			right: 1rem;
			position: absolute;
		}

.form-flex {
	display: flex;
	flex-direction: column;
	gap: 1rem;
}

.file-upload .file-upload-with-preview {
		display: flex;
		gap: 1rem;
	}

.file-upload .file-upload-with-preview img {
			height: 8rem;
			border: 0.2rem solid var(--border-accent);
		}

.file-upload .file-upload-with-preview img.avatar {
			width: 8rem;
		}

.file-upload .file-upload-with-preview img.header {
			width: 24rem;
		}

.file-input-with-image-description {
	display: flex;
	flex-direction: column;
	justify-content: space-around;
	gap: 0.5rem;
}

.file-input-with-image-description .delete-header-button,
	.file-input-with-image-description .delete-avatar-button {
		margin-top: 0.5rem;
		font-size: 1rem;
	}

/*
	Normalize mock profile and make profile
	header preview pop a bit nicer.
*/

.profile {
	padding: 0;
}

.profile > .profile-header {
		margin-bottom: 0;
		border: 0.1rem solid var(--gray1);
	}

.user-profile .profile {
		max-width: 42rem;
	}

.user-profile .file-input-with-image-description {
		max-width: 100%;
		width: 100%;
	}

.user-profile .overview {
		display: flex;
		flex-direction: column;
		gap: 1rem;
	}

.user-profile .overview .files {
			width: 100%;
			display: flex;
			flex-direction: column;
			justify-content: center;
			gap: 1rem;
		}

.user-profile .overview .files span {
				font-style: italic;
			}

.user-profile .theme, .user-profile .form-field.radio {
		display: flex;
		flex-direction: column;
		gap: 0.5rem;
	}

.user-profile fieldset {
		margin: 0;
		padding: 0.5rem 1rem 1rem 1rem;
		max-width: -moz-fit-content;
		max-width: fit-content;
		border: 0.1rem solid var(--gray1);
		border-radius: 0.1rem;
	}

.user-profile fieldset >legend {
			font-weight: bold;
		}

.user-profile fieldset .fields {
			display: flex;
			flex-direction: column;
			gap: 0.5rem;
		}

.user-profile fieldset .fields .entry {
				display: flex;
				gap: 0.5rem;
			}

.migration-details {
	display: flex;
	flex-direction: column;
	gap: 1rem;

	background-color: var(--gray2);
	padding: 1rem;
	max-width: -moz-fit-content;
	max-width: fit-content;
	border-radius: var(--br);
}

.migration-details > div {
		display: flex;
		flex-direction: column;
		gap: 0.25rem;
	}

.migration-details > div > dd {
			font-weight: bold;
			word-wrap: anywhere;
		}

.user-migration-alias .aliases {
		display: flex;
		flex-direction: column;
		gap: 0.5rem;
	}

form {
	display: flex;
	flex-direction: column;
	gap: 0.5rem;
}

.form-field label {
	font-weight: bold;
}

.form-field.file {
	display: flex;
	position: relative;
	overflow: hidden;
}

.form-field.file .label-wrapper {
		width: -moz-fit-content;
		width: fit-content;
		display: flex;
		flex-direction: column;
	}

.form-field.file .label-wrapper:focus-visible {
			outline: 0.15rem dashed var(--button-focus-border);
			outline-offset: -0.15rem;
		}

.form-field.file .form-info {
		position: absolute;
		font-weight: initial;
		align-self: end;
		margin-left: 4.25rem;
		margin-bottom: 0.3rem;
	}

.form-field.file .form-info .error {
			padding: 0.1rem;
			line-height: 1.4rem;
		}

.checkbox-list .header, .checkbox-list .entry {
		display: grid;
		gap: 0 1rem;
	}

.pageable-list {
	display: flex;
	flex-direction: column;
	gap: 0.5rem;
}

.pageable-list .entries {
		color: var(--fg);
		border: 0.1rem solid var(--gray1);
	}

.pageable-list .prev-next {
		display: flex;
		justify-content: space-between;
	}

/*
	Make sure the "or use the import/export
	thing" link is at the bottom of the page.
*/

section > div.domain-block,
section > div.domain-allow {
	height: 100%;
}

section > div.domain-block > a, section > div.domain-allow > a {
		margin-top: auto;
	}

section > div.domain-limit-details form {
		gap: 1rem;
	}

/*
			Align policy options radio thingy
			vertically as it looks a bit better.
		*/

section > div.domain-limit-details form> .form-field.radio {
			display: flex;
			flex-direction: column;
		}

/*
			Style the cheat sheet explainer
			for policies a little bit nicely.
		*/

section > div.domain-limit-details form div.form-section-docs details[open]::details-content {
				padding: 1rem;
				background-color: var(--gray2);
				max-width: -moz-fit-content;
				max-width: fit-content;
				border-radius: var(--br);
			}

section > div.domain-limit-details form div.form-section-docs details dl {
				display: flex;
				flex-direction: column;
				gap: 1rem;
			}

section > div.domain-limit-details form div.form-section-docs details dl dt {
					font-weight: bold;
				}

section > div.domain-limit-details form div.form-section-docs details dl dd {
					margin-left: 1rem;
				}

.domain-actions-list p {
		margin-top: 0;
	}

.domain-actions-list .filter {
		display: flex;
		gap: 0.5rem;
	}

.domain-actions-list .filter button {
			width: 100%;
		}

.domain-actions-list .entry {
		padding: 0.5rem;
		margin: 0.2rem 0;
	}

.domain-actions-list .entry #domain {
			flex: 1 1 auto;
			overflow: hidden;
			white-space: nowrap;
			text-overflow: ellipsis;
		}

.bulk h2 {
	display: flex;
	justify-content: space-between;
}

.emoji-list {
	background: var(--list-entry-bg);
}

.emoji-list .header .form-field {
		flex: 1 1 auto;
	}

.emoji-list .entry {
		flex-direction: column;
	}

.emoji-list .entry b {
			padding-left: 0.4rem;
		}

.emoji-list .entry .emoji-group {
			display: flex;
			flex-wrap: wrap;
		}

.emoji-list .entry .emoji-group a {
				border-radius: var(--br);
				padding: 0.4rem;
				line-height: 0;
			}

.emoji-list .entry .emoji-group a img {
					height: 2rem;
					width: 2rem;
					object-fit: contain;
					vertical-align: middle;
				}

.emoji-list .entry .emoji-group a:hover {
					background: var(--list-entry-hover-bg);
				}

.emoji-list .entry:hover {
			background: inherit;
		}

.toot {
	padding-top: 0.5rem;
}

.toot .contentgrid {
		padding: 0 0.5rem;
	}

@media screen and (max-width: 60rem) {
	/* vertical layout */
	#root {
		padding: 0.5rem;
		margin: 0;
		grid-template-columns: 100%;
		grid-template-rows: auto auto;
	}

		#root div.sidebar {
			justify-self: auto;
			margin-bottom: 0;
		}

		#root div.sidebar, #root section.with-sidebar {
			border-top-left-radius: var(--br);
			border-top-right-radius: var(--br);
			border-bottom-left-radius: var(--br);
			border-bottom-right-radius: var(--br);
		}

		#root section.with-sidebar {
			grid-column: 1;
			padding: 1rem;
		}

		#root div.sidebar a:first-child h2 {
			border-top-right-radius: var(--br);
		}

	.user-profile .overview {
		grid-template-columns: auto;
		grid-template-rows: auto 1fr;
	}

	main section {
		padding: 0.75rem;
	}

	.domain-actions-list .filter {
		flex-direction: column;
	}
}

.combobox-wrapper {
  display: flex;
  flex-direction: column;
}

.combobox-wrapper input[aria-expanded="true"] {
		border-bottom: none;
	}

.combobox {
  height: 2.5rem;
  font-size: 1rem;
  line-height: 1.5rem;
}

.popover {
  position: relative;
  z-index: 50;
  display: flex;
  max-height: min(var(--popover-available-height,300px),300px);
  flex-direction: column;
  overflow: auto;
  overscroll-behavior: contain;
	border: 0.15rem solid var(--orange2);
	background: var(--bg-accent);
}

.combobox-item {
  display: flex;
  cursor: pointer;
  scroll-margin: 0.5rem;
  align-items: center;
  gap: 0.5rem;
  padding: 0.5rem;
	line-height: 1.5rem;
	border-bottom: 0.15rem solid var(--gray3);
}

.combobox-item:last-child {
		border: none;
	}

.combobox-item img {
		height: 1.5rem;
		width: 1.5rem;
		object-fit: contain;
	}

.combobox-item:hover {
	background: var(--button-hover-bg);
	color: var(--button-fg);
}

.combobox-item[data-active-item] {
  background: var(--button-hover-bg);
  color: hsl(204 20% 100%);
}

.row {
	display: flex;
	gap: 0.5rem;
}

.emoji-detail {
	display: flex;
	flex-direction: column;
	gap: 1rem !important;
}

.emoji-detail > a {
		align-self: flex-start;
	}

.emoji-detail .emoji-header {
		display: flex;
		align-items: center;
		gap: 0.5rem;
	}

.emoji-detail .emoji-header div {
			display: flex;
			flex-direction: column;
			gap: 0.5rem;
		}

.emoji-detail .emoji-header img {
			height: 8.5rem;
			width: 8.5rem;
			border: 0.2rem solid var(--border-accent);
			object-fit: contain;
			padding: 0.5rem;
		}

.emoji-detail .update-category .combobox-wrapper button {
			font-size: 1rem;
			margin: 0.15rem 0;
		}

.emoji-detail .update-category .row {
			margin-top: 0.1rem;
		}

.emoji-detail .update-image {
		display: flex;
		flex-direction: column;
		gap: 0.5rem;
	}

.left-border {
	border-left: 0.2rem solid var(--border-accent);
	padding-left: 0.4rem;
}

.parse-emoji .parsed {
		margin-top: 0.5rem;
		display: flex;
		flex-direction: column;
		gap: 1rem;
	}

.parse-emoji .parsed span {
			margin-bottom: -0.5rem;
		}

.parse-emoji .parsed .action-buttons {
			gap: 1rem;
		}

.parse-emoji .parsed .checkbox-list .entry {
				grid-template-columns: auto auto 1fr;
			}

.parse-emoji .parsed .checkbox-list .emoji {
				height: 2rem;
				width: 2rem;
				margin: 0;
			}

.info {
	color: var(--info-fg);
	background: var(--info-bg);
	padding: 0.25rem;
	border-radius: var(--br);

	display: flex;
	gap: 0.5rem;
	align-items: center;
}

.info a {
		color: var(--info-link);
	}

.info p {
		margin-top: 0;
	}

.mutation-button {
	width: -moz-fit-content;
	width: fit-content;
	display: flex;
	flex-direction: column;
	gap: 1rem;
}

button.with-icon,
.button.with-icon {
	display: flex;
	align-content: center;
	padding-right: calc(0.5rem + var(--fa-fw));
}

button.with-icon .fa, .button.with-icon .fa {
		align-self: center;
	}

button.with-padding {
	padding: 0.5rem calc(0.5rem + var(--fa-fw));
}

.tab-buttons {
	display: flex;
	max-width: -moz-fit-content;
	max-width: fit-content;
	justify-content: space-between;
	gap: 0.15rem;
}

button.tab-button {
	border-top-left-radius: var(--br);
	border-top-right-radius: var(--br);
	border-bottom-left-radius: 0;
	border-bottom-right-radius: 0;
	box-shadow: none;
	background: var(--blue1);
}

button.tab-button:hover {
		background: var(--button-hover-bg);
	}

button.tab-button {

	text-overflow: ellipsis;
	overflow: hidden;
	white-space: nowrap;

	font-size: 1rem;
}

@media screen and (max-width: 20rem) {

button.tab-button {
		font-size: 0.75rem
}
	}

button.tab-button.active {
		background: var(--button-bg);
		cursor: default;
	}

.loading-icon {
	align-self: flex-start;
}

.fadeout {
	animation-name: fadeout;
	animation-duration: 0.5s;
	animation-delay: 2s;
	animation-fill-mode: forwards;
}

.domain-perm-import-list .checkbox-list-wrapper {
		display: grid;
		gap: 1rem;
	}

.domain-perm-import-list .checkbox-list {
		overflow-x: auto;
	}

.domain-perm-import-list .checkbox-list .header {
			align-items: center;
		}

.domain-perm-import-list .checkbox-list .header input[type="checkbox"] {
				height: 1.5rem;
			}

.domain-perm-import-list .checkbox-list .entry {
			grid-template-columns: auto max(50%, 14rem) 1fr;
			column-gap: 1rem;
			align-items: center;
		}

.domain-perm-import-list .checkbox-list .entry .domain-input {
				display: grid;
				grid-template-columns: 1fr var(--fa-fw);
				gap: 0.5rem;
			}

.domain-perm-import-list .checkbox-list .entry .domain-input #icon {
					align-self: center;
				}

.domain-perm-import-list .checkbox-list .entry .domain-input #icon .permission-already-exists {
						color: var(--green1);
					}

.domain-perm-import-list .checkbox-list .entry .domain-input #icon .suggest-changes {
						color: var(--orange2);
					}

.domain-perm-import-list .checkbox-list .entry p {
				margin: 0;
			}

.domain-perm-import-list .set-comment-checkbox {
		display: flex;
		flex-direction: column;
		gap: 0.25rem;

		padding: 0.5rem 1rem 1rem 1rem;
		width: 100%;
		border: 0.1rem solid var(--gray1);
		border-radius: 0.1rem;
	}

.import-export p {
		margin: 0;
	}

.import-export .export-file {
		display: flex;
		gap: 0.7rem;
		align-items: center;
	}

.import-export .form-field.radio {
		display: flex;
		flex-direction: column;
		margin-left: 0.5rem;
	}

.import-export .button-grid {
		display: inline-grid;
		grid-template-columns: auto auto auto;
		align-self: start;
		gap: 0.5rem;
	}

.import-export .button-grid button {
			width: 100%;
		}

@media screen and (max-width: 35rem) {
		.import-export .button-grid {
			grid-template-columns: auto auto;
		}

			.import-export .button-grid b { /* filler item */
				display: none;
			}

			.import-export .button-grid > * {
				grid-column: 1 / span 2;
				justify-self: start;
			}

			.import-export .button-grid .export-file-button, .import-export .button-grid .export-file {
				grid-column: span 1;
			}
}

.update-hints {
	background: var(--list-entry-alternate-bg);
	border: 0.1rem solid var(--border-accent);
	/* border-radius: $br; */
	padding: 0.5rem;
	display: flex;
	flex-direction: column;
}

.update-hints .hints {
		max-width: 100%;
		align-self: start;
		align-items: center;
		margin: 1rem 0;
		display: inline-grid;
		grid-template-columns: auto auto auto auto;
		gap: 1rem;
	}

.export-format-table-wrapper {
	overflow-x: auto;
}

.export-format-table-wrapper, .export-format-table-wrapper th, .export-format-table-wrapper td {
		border: 0.1rem solid var(--gray1) !important;
	}

.export-format-table-wrapper .export-format-table {
		background: var(--list-entry-alternate-bg);
		border-style: hidden;
		border-collapse: collapse;
	}

.export-format-table-wrapper .export-format-table th, .export-format-table-wrapper .export-format-table td {
			padding: 0.3rem;
		}

.export-format-table-wrapper .export-format-table th {
			background: var(--list-entry-bg);
		}

.export-format-table-wrapper .export-format-table td {
			text-align: center;
		}

.export-format-table-wrapper .export-format-table td .fa-check {
				color: var(--green1);
			}

.export-format-table-wrapper .export-format-table td .fa-times {
				color: var(--error3);
			}

.form-field.radio, .form-field.radio label {
		display: flex;
		gap: 0.5rem;
	}

.form-field.radio input {
		width: auto;
		place-self: center;
	}

.reports-view .report {
		display: flex;
		flex-direction: column;
		flex-wrap: nowrap;
		gap: 0.5rem;
		color: var(--fg);
		border-left: 0.3rem solid var(--border-accent);
	}

.reports-view .report .username-lozenge {
			display: flex;
			flex-wrap: nowrap;
			height: 100%;
			align-items: center;
			padding-top: 0;
			padding-bottom: 0;
		}

.reports-view .report .username-lozenge .fa {
				flex-shrink: 0;
			}

.reports-view .report .report-byline {
			max-width: -moz-fit-content;
			max-width: fit-content;
		}

.reports-view .report .info-list {
			border: none;
		}

.reports-view .report .info-list .info-list-entry {
				background: none;
				padding: 0;
			}

.reports-view .report .info-list .info-list-entry .report-target .username-lozenge {
					color: var(--bg);
				}

.reports-view .report .info-list .info-list-entry .reported-by .username-lozenge {
					color: var(--fg);
					font-weight: initial;
					border-radius: 0;
					background: none;
				}

.reports-view .report.resolved {
			border-left: 0.3rem solid var(--list-entry-bg);
		}

.reports-view .report.resolved .info-list,
			.reports-view .report.resolved .info-list .info-list-entry .reported-by .username-lozenge {
				color: var(--fg-reduced);
			}

.reports-view .report.resolved:hover {
				border-color: var(--fg-accent);
			}

.reports-view .report.detail {
			border: none;
			padding: 0;
		}

.report-detail .info-list.overview {
			margin-top: 1rem;
		}

.report-detail .info-list .username-lozenge {
			display: flex;
			flex-wrap: nowrap;
			height: 100%;
			align-items: center;
			padding-top: 0;
			padding-bottom: 0;
			max-width: -moz-fit-content;
			max-width: fit-content;
		}

.report-detail .info-list .username-lozenge .fa {
				flex-shrink: 0;
			}

.report-detail .report-statuses {
		width: min(100%, 50rem);
	}

.report-detail .report-statuses .thread {
			display: flex;
			flex-direction: column;
			gap: 2rem;
			padding: 0;
		}

.accounts-view .pageable-list .username-lozenge {
			line-height: inherit;
			color: var(--fg);
			font-weight: initial;
			width: 100%;
			border-radius: 0;
			background: var(--list-entry-bg);
		}

.accounts-view .pageable-list .username-lozenge .fa {
				align-self: center;
			}

.accounts-view .pageable-list .username-lozenge:nth-child(even) {
				background: var(--list-entry-alternate-bg);
			}

.accounts-view .pageable-list .username-lozenge .acct {
				color: var(--link-fg);
			}

.account-detail {
	display: flex;
	flex-direction: column;
	gap: 1rem;
}

.account-detail .profile {
		overflow: hidden;
		max-width: 60rem;
		margin-top: 1rem;
	}

.account-detail h4, .account-detail h3, .account-detail h2 {
		margin-top: 0;
		margin-bottom: 0;
	}

.account-detail .action-buttons {
		display: flex;
		gap: 0.5rem;
		align-items: center;
	}

.username-lozenge {
	line-height: 1.3rem;
	display: inline-block;
	background: var(--fg-accent);
	color: var(--bg);
	border-radius: var(--br);
	padding: 0.15rem;
	font-weight: bold;
	text-decoration: none;
}

.username-lozenge .acct {
		word-break: break-all;
	}

.username-lozenge.suspended {
		background: var(--bg-accent);
		color: var(--fg);
		text-decoration: line-through;
	}

.username-lozenge.local {
		background: var(--green1);
	}

.pseudolink {
	cursor: pointer;
	text-decoration: none;
}

.pseudolink:focus-visible {
		outline: 0.15rem dotted var(--button-focus-border);
	}

.info-list {
	border: 0.1rem solid var(--gray1);
	display: flex;
	flex-direction: column;
}

.info-list .info-list-entry {
		background: var(--list-entry-bg);
		border: 0.1rem solid transparent;
		padding: 0.25rem;
	}

.info-list .info-list-entry:nth-child(even) {
			background: var(--list-entry-alternate-bg);
		}

.info-list .info-list-entry {

		display: grid;
		grid-template-columns: max(20%, 10rem) 1fr;
}

.info-list .info-list-entry dt {
			font-weight: bold;
		}

.info-list .info-list-entry dd {
			word-break: break-word;
		}

/*
				Make sure any fa icons used in keys
				or values etc. are properly aligned.
			*/

.info-list .info-list-entry dt .fa, .info-list .info-list-entry dd .fa, .info-list .info-list-entry span .fa {
				vertical-align: middle;
			}

.domain-permission-drafts-view .domain-permission-draft,
	.domain-permission-drafts-view .domain-permission-exclude,
	.domain-permission-drafts-view .domain-permission-subscription,
	.domain-permission-excludes-view .domain-permission-draft,
	.domain-permission-excludes-view .domain-permission-exclude,
	.domain-permission-excludes-view .domain-permission-subscription,
	.domain-permission-subscriptions-view .domain-permission-draft,
	.domain-permission-subscriptions-view .domain-permission-exclude,
	.domain-permission-subscriptions-view .domain-permission-subscription,
	.domain-permission-subscriptions-preview .domain-permission-draft,
	.domain-permission-subscriptions-preview .domain-permission-exclude,
	.domain-permission-subscriptions-preview .domain-permission-subscription {
		display: flex;
		flex-direction: column;
		flex-wrap: nowrap;
		gap: 0.5rem;
	}

.domain-permission-drafts-view .domain-permission-draft.block, .domain-permission-drafts-view .domain-permission-exclude.block, .domain-permission-drafts-view .domain-permission-subscription.block, .domain-permission-excludes-view .domain-permission-draft.block, .domain-permission-excludes-view .domain-permission-exclude.block, .domain-permission-excludes-view .domain-permission-subscription.block, .domain-permission-subscriptions-view .domain-permission-draft.block, .domain-permission-subscriptions-view .domain-permission-exclude.block, .domain-permission-subscriptions-view .domain-permission-subscription.block, .domain-permission-subscriptions-preview .domain-permission-draft.block, .domain-permission-subscriptions-preview .domain-permission-exclude.block, .domain-permission-subscriptions-preview .domain-permission-subscription.block {
			border-left: 0.3rem solid var(--error3);
		}

.domain-permission-drafts-view .domain-permission-draft.allow, .domain-permission-drafts-view .domain-permission-exclude.allow, .domain-permission-drafts-view .domain-permission-subscription.allow, .domain-permission-excludes-view .domain-permission-draft.allow, .domain-permission-excludes-view .domain-permission-exclude.allow, .domain-permission-excludes-view .domain-permission-subscription.allow, .domain-permission-subscriptions-view .domain-permission-draft.allow, .domain-permission-subscriptions-view .domain-permission-exclude.allow, .domain-permission-subscriptions-view .domain-permission-subscription.allow, .domain-permission-subscriptions-preview .domain-permission-draft.allow, .domain-permission-subscriptions-preview .domain-permission-exclude.allow, .domain-permission-subscriptions-preview .domain-permission-subscription.allow {
			border-left: 0.3rem solid var(--green1);
		}

.domain-permission-drafts-view .domain-permission-draft:hover, .domain-permission-drafts-view .domain-permission-exclude:hover, .domain-permission-drafts-view .domain-permission-subscription:hover, .domain-permission-excludes-view .domain-permission-draft:hover, .domain-permission-excludes-view .domain-permission-exclude:hover, .domain-permission-excludes-view .domain-permission-subscription:hover, .domain-permission-subscriptions-view .domain-permission-draft:hover, .domain-permission-subscriptions-view .domain-permission-exclude:hover, .domain-permission-subscriptions-view .domain-permission-subscription:hover, .domain-permission-subscriptions-preview .domain-permission-draft:hover, .domain-permission-subscriptions-preview .domain-permission-exclude:hover, .domain-permission-subscriptions-preview .domain-permission-subscription:hover {
			border-color: var(--fg-accent);
		}

.domain-permission-drafts-view .domain-permission-draft .info-list, .domain-permission-drafts-view .domain-permission-exclude .info-list, .domain-permission-drafts-view .domain-permission-subscription .info-list, .domain-permission-excludes-view .domain-permission-draft .info-list, .domain-permission-excludes-view .domain-permission-exclude .info-list, .domain-permission-excludes-view .domain-permission-subscription .info-list, .domain-permission-subscriptions-view .domain-permission-draft .info-list, .domain-permission-subscriptions-view .domain-permission-exclude .info-list, .domain-permission-subscriptions-view .domain-permission-subscription .info-list, .domain-permission-subscriptions-preview .domain-permission-draft .info-list, .domain-permission-subscriptions-preview .domain-permission-exclude .info-list, .domain-permission-subscriptions-preview .domain-permission-subscription .info-list {
			border: none;
		}

.domain-permission-drafts-view .domain-permission-draft .info-list .info-list-entry, .domain-permission-drafts-view .domain-permission-exclude .info-list .info-list-entry, .domain-permission-drafts-view .domain-permission-subscription .info-list .info-list-entry, .domain-permission-excludes-view .domain-permission-draft .info-list .info-list-entry, .domain-permission-excludes-view .domain-permission-exclude .info-list .info-list-entry, .domain-permission-excludes-view .domain-permission-subscription .info-list .info-list-entry, .domain-permission-subscriptions-view .domain-permission-draft .info-list .info-list-entry, .domain-permission-subscriptions-view .domain-permission-exclude .info-list .info-list-entry, .domain-permission-subscriptions-view .domain-permission-subscription .info-list .info-list-entry, .domain-permission-subscriptions-preview .domain-permission-draft .info-list .info-list-entry, .domain-permission-subscriptions-preview .domain-permission-exclude .info-list .info-list-entry, .domain-permission-subscriptions-preview .domain-permission-subscription .info-list .info-list-entry {
				background: none;
				padding: 0;
			}

.domain-permission-drafts-view .domain-permission-draft .action-buttons, .domain-permission-drafts-view .domain-permission-exclude .action-buttons, .domain-permission-drafts-view .domain-permission-subscription .action-buttons, .domain-permission-excludes-view .domain-permission-draft .action-buttons, .domain-permission-excludes-view .domain-permission-exclude .action-buttons, .domain-permission-excludes-view .domain-permission-subscription .action-buttons, .domain-permission-subscriptions-view .domain-permission-draft .action-buttons, .domain-permission-subscriptions-view .domain-permission-exclude .action-buttons, .domain-permission-subscriptions-view .domain-permission-subscription .action-buttons, .domain-permission-subscriptions-preview .domain-permission-draft .action-buttons, .domain-permission-subscriptions-preview .domain-permission-exclude .action-buttons, .domain-permission-subscriptions-preview .domain-permission-subscription .action-buttons {
			display: flex;
			gap: 0.5rem;
			align-items: center;
		}

.domain-permission-drafts-view .domain-permission-draft .action-buttons > .mutation-button
			> button, .domain-permission-drafts-view .domain-permission-exclude .action-buttons > .mutation-button
			> button, .domain-permission-drafts-view .domain-permission-subscription .action-buttons > .mutation-button
			> button, .domain-permission-excludes-view .domain-permission-draft .action-buttons > .mutation-button
			> button, .domain-permission-excludes-view .domain-permission-exclude .action-buttons > .mutation-button
			> button, .domain-permission-excludes-view .domain-permission-subscription .action-buttons > .mutation-button
			> button, .domain-permission-subscriptions-view .domain-permission-draft .action-buttons > .mutation-button
			> button, .domain-permission-subscriptions-view .domain-permission-exclude .action-buttons > .mutation-button
			> button, .domain-permission-subscriptions-view .domain-permission-subscription .action-buttons > .mutation-button
			> button, .domain-permission-subscriptions-preview .domain-permission-draft .action-buttons > .mutation-button
			> button, .domain-permission-subscriptions-preview .domain-permission-exclude .action-buttons > .mutation-button
			> button, .domain-permission-subscriptions-preview .domain-permission-subscription .action-buttons > .mutation-button
			> button {
				font-size: 1rem;
				line-height: 1rem;
			}

.domain-permission-details .info-list, .domain-permission-draft-details .info-list, .domain-permission-exclude-details .info-list, .domain-permission-subscription-details .info-list, .domain-limit-details .info-list {
		margin-top: 1rem;
	}

.domain-permission-details dd.permission-type, .domain-permission-drafts-view dd.permission-type, .domain-permission-draft-details dd.permission-type, .domain-permission-subscriptions-view dd.permission-type, .domain-permission-subscription-details dd.permission-type, .domain-permission-subscriptions-preview dd.permission-type {
		display: flex;
		gap: 0.35rem;
		align-items: center;
	}

.domain-permission-subscription-details > .list > .entries > .perm-preview {
		gap: 0.5rem;
	}

.domain-permission-subscription-details > .perm-issue > b > code {
		background: var(--info-bg);
		padding: 0;
	}

.domain-permission-subscription-title {
	font-size: 1.2rem;
	font-weight: bold;
}

.domain-permission-subscription-create,
.domain-permission-subscription-update {
	gap: 1rem;
}

.domain-permission-subscription-create .password-show-hide, .domain-permission-subscription-update .password-show-hide {
		display: flex;
		gap: 0.5rem;
	}

.domain-permission-subscription-create .password-show-hide .form-field.text, .domain-permission-subscription-update .password-show-hide .form-field.text {
			flex: 1;
		}

.domain-permission-subscription-create .password-show-hide .password-show-hide-toggle, .domain-permission-subscription-update .password-show-hide .password-show-hide-toggle {
			font-size: 1rem;
			line-height: 1.4rem;
			align-self: flex-end;
		}

.domain-permission-subscription-remove,
.domain-permission-subscription-test {
	gap: 1rem;
}

.tokens-view .token-info .info-list {
			border: none;
			width: 100%;
		}

.tokens-view .token-info .info-list .info-list-entry {
				background: none;
				padding: 0;
			}

.tokens-view .token-info .action-buttons {
			margin-top: 0.5rem;
		}

.tokens-view .token-info .action-buttons > .mutation-button
			> button {
				font-size: 1rem;
				line-height: 1rem;
			}

.access-token-receive-form > .access-token-frame {
		background-color: var(--gray2);
		width: 100%;
		padding: 0.25rem;
		border-radius: var(--br-inner);
		white-space: pre;
		overflow-x: auto;
		-webkit-overflow-scrolling: touch;
	}

.access-token-receive-form .closed {
		text-align: center;
	}

.applications-view .application .info-list {
			border: none;
			width: 100%;
		}

.applications-view .application .info-list .info-list-entry {
				background: none;
				padding: 0;
			}

.application-details .info-list {
		margin-top: 1rem;
	}

.application-details .info-list > .info-list-entry > dd > button {
			font-size: medium;
			padding-top: 0;
			padding-bottom: 0;
		}

.instance-info-view .info-list .info-list-entry {
		/*
			Some of the labels are quite
			long so ensure there's enough
			gap when they're wrapped.
		*/
		gap: 1rem;
	}

/*
		Make sure ellipsis works
		properly for v. long domains.
	*/

.instance-info-view .list.domain-perm-list > .entry > .domain {
		display: inline-block;
		font-weight: bold;
	}

/*
		Make sure we can break.
	*/

.instance-info-view .list.domain-perm-list > .entry > .public_comment {
		word-wrap: anywhere;
	}

/*
		Disable the hover effects as
		these entries aren't clickable.
	*/

.instance-info-view .list.domain-perm-list > .entry:hover {
		background: var(--list-entry-bg);
	}

.instance-info-view .list.domain-perm-list > .entry:nth-child(2n):hover {
		background: var(--list-entry-alternate-bg);
	}

.instance-info-view .list.domain-perm-list > .entry:active, .instance-info-view .list.domain-perm-list > .entry:focus, .instance-info-view .list.domain-perm-list > .entry:hover, .instance-info-view .list.domain-perm-list > .entry:target {
			border-color: var(--gray1);
			border-top-color: transparent;
		}

.instance-rules {
	list-style-position: inside;
	margin: 0;
	padding: 0;
}

.instance-rules a.rule {
		display: grid;
		grid-template-columns: 1fr auto;
		align-items: center;
		color: var(--fg);
		text-decoration: none;
		background: var(--status-bg);
		padding: 1rem;
		margin: 0.5rem 0;
		border-radius: var(--br);
		line-height: 2rem;
		position: relative;
	}

.instance-rules a.rule:hover {
			color: var(--fg-accent);
		}

.instance-rules a.rule:hover .edit-icon {
				display: inline;
			}

.instance-rules a.rule .edit-icon {
			display: none;
			font-size: 1rem;
			line-height: 1.5rem;
		}

.instance-rules a.rule li {
			font-size: 1.75rem;
			padding: 0;
			margin: 0;
		}

.instance-rules a.rule li h2 {
				margin: 0;
				margin-top: 0 !important;
				display: inline-block;
				font-size: 1.5rem;
			}

.instance-rules a.rule span {
			color: var(--fg-reduced);
		}

.http-header-permissions .list {
		/*
			Space this page out a bit, it
			looks too tight otherwise.
		*/
		margin: 1rem 0;
	}

/*
			Visually separate the key + value for
			each entry, and show the value in
			reasonably-sized monospace font.
		*/

.http-header-permissions .list .entries > .entry {
			display: grid;
			grid-template-columns: max(20%, 10rem) 1fr;
		}

.http-header-permissions .list .entries > .entry dt {
				font-weight: bold;
			}

.http-header-permissions .list .entries > .entry dd {
				font-family: "Noto Sans Mono", monospace;
			}

.http-header-permission-details .info-list {
		margin-top: 1rem;
	}

.admin-debug-apurl {
	width: 100%;
}

.admin-debug-apurl .prism-highlighted {
		max-width: 40rem;
	}

/*
			Normally we'd want to use a scrollbar for pre
			and code, but it actually looks a bit better
			to wrap here because there are many long lines.
		*/

.admin-debug-apurl .prism-highlighted pre, .admin-debug-apurl .prism-highlighted code {
			white-space: pre-wrap;
		}

.interaction-default-settings .interaction-policy-section {
		padding: 1rem;
		display: none;
	}

.interaction-default-settings .interaction-policy-section.active {
			display: flex;
		}

.interaction-default-settings .interaction-policy-section {
		
		flex-direction: column;
		gap: 1rem;
		border: 0.15rem solid var(--input-border);
}

.interaction-default-settings .interaction-policy-section fieldset {
			display: flex;
			flex-direction: column;
			gap: 0.5rem;

			margin: 0;
			padding: 0.5rem 1rem 1rem 1rem;

			border: var(--boxshadow-border);
			border-radius: 0.1rem;
			box-shadow: var(--boxshadow);
		}

.interaction-default-settings .interaction-policy-section fieldset >legend {
				display: flex;
				gap: 0.5rem;
				align-items: center;
				font-weight: bold;
				font-size: large;
			}

.interaction-default-settings .interaction-policy-section fieldset hr {
				width: 100%;
			}

.interaction-default-settings .interaction-policy-section fieldset .something-else {
				display: flex;
				flex-direction: column;
				gap: 0.5rem;
				margin-top: -0.3rem;
			}

.export-data .export-buttons-wrapper {
		display: grid;
		max-width: -moz-fit-content;
		max-width: fit-content;
		gap: 0.5rem;
	}

.export-data .export-buttons-wrapper .stats-and-button {
			display: grid;
			grid-template-columns: 13rem 1fr;
			align-items: center;
			gap: 0.25rem;
		}

.export-data .export-buttons-wrapper .stats-and-button .mutation-button {
				width: 100%;
			}

.export-data .export-buttons-wrapper .stats-and-button .mutation-button button {
					font-size: 1rem;
					width: 100%;
				}

@media screen and (max-width: 35rem) {

.export-data .export-buttons-wrapper {
			gap: 1rem
	}
			
			.export-data .export-buttons-wrapper .stats-and-button {
				grid-template-columns: auto;
			}
		}

.interaction-requests-view .interaction-request {
		display: flex;
		flex-direction: column;
		flex-wrap: nowrap;
		gap: 0.5rem;
		color: var(--fg);
	}

.interaction-requests-view .interaction-request .info-list {
			border: none;
		}

.interaction-requests-view .interaction-request .info-list .info-list-entry {
				grid-template-columns: max(20%, 8rem) 1fr;
				background: none;
				padding: 0;
			}

.interaction-requests-view .interaction-request .action-buttons {
			display: flex;
			gap: 0.5rem;
			align-items: center;
		}

.interaction-requests-view .interaction-request .action-buttons > .mutation-button
			> button {
				font-size: 1rem;
				line-height: 1rem;
			}

.interaction-request-detail .overview {
		margin-top: 1rem;
	}

.interaction-request-detail h2 {
		font-size: 1rem;
	}

.interaction-request-detail .thread .status .status-info {
		border-bottom-left-radius: var(--br);
		border-bottom-right-radius: var(--br);
	}

.interaction-request-detail .action-buttons {
		display: flex;
		gap: 0.5rem;
		align-items: center;
	}

@media screen and (orientation: portrait) {
	.reports .report .byline {
		grid-template-columns: 1fr;
	}

		.reports .report .byline .report-status {
			grid-row: 1;
		}
}

[role="button"] {
	cursor: pointer;
}

@keyframes fadeout {
	from {
		opacity: 1;
	}
	to {
		opacity: 0;
	}
}

@media (prefers-reduced-motion) {
	.fa-spin {
		animation: none;
	}
}

.monospace {
	font-family: "Noto Sans Mono", monospace;
}



