
/*
	GoToSocial
	Copyright (C) GoToSocial Authors admin@gotosocial.org
	SPDX-License-Identifier: AGPL-3.0-or-later

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU Affero General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU Affero General Public License for more details.

	You should have received a copy of the GNU Affero General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

.about {
	display: flex;
	flex-direction: column;
	gap: 2rem;
	padding: 2rem;

	background: var(--bg-accent);
	box-shadow: var(--boxshadow);
	border: var(--boxshadow-border);
	border-radius: var(--br);
}

.about .about-section h1, .about .about-section h2, .about .about-section h3, .about .about-section h4, .about .about-section h5 {
			margin-top: 0;
		}

